@@ -57,7 +57,8 @@ void MigrationAgent::configure(WId windowId)
     dlg->resize(600, 300);
 
     if (windowId) {
-        KWindowSystem::setMainWindow(dlg, windowId);
+        dlg->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(dlg->windowHandle(), windowId);
     }
     dlg->show();
 }
