@@ -48,9 +48,6 @@
 
 SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::SubscriptionDialogOptions option)
     : QDialog(parent)
-    , m_session(nullptr)
-    , m_subscriptionChanged(false)
-    , m_lineEdit(nullptr)
     , m_filter(new SubscriptionFilterProxyModel(this))
     , m_model(new QStandardItemModel(this))
 {
@@ -71,7 +68,7 @@ SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::Subs
 
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mainWidget->setLayout(mainLayout);
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
@@ -329,7 +326,6 @@ void SubscriptionDialog::applyChanges()
 
 SubscriptionFilterProxyModel::SubscriptionFilterProxyModel(QObject *parent)
     : KRecursiveFilterProxyModel(parent)
-    , m_checkedOnly(false)
 {
 }
 
